// @flow
import React, { useState } from 'react';
import Pdf from 'react-native-pdf';
import { contextualStyleSheet } from 'react-native-contextual-dark-mode';

type DocumentPreviewerProps = {
    uri: string;
    onLoadingError: () => void;
}

const DocumentPreviewer = ({ uri, onLoadingError }: DocumentPreviewerProps) => {
    const [error, setError] = useState<boolean>(false);

    const onError = (errorObject: Object) => {
        setError(true);
        // eslint-disable-next-line no-console
        console.log(`Could not load document with the following error: ${errorObject.toString()}`);
    };

    if (error || !uri) {
        return onLoadingError();
    }

    return (
        <Pdf
            source={{ uri }}
            style={s.pdfContainer}
            onError={onError}
            trustAllCerts={false}
        />
    );
};

export default DocumentPreviewer;

const s = contextualStyleSheet((darkMode) => ({
    pdfContainer: {
        flex: 1,
        backgroundColor: darkMode ? 'black' : 'white',
    },
}));
